@@ -53,8 +53,7 @@ setGeneric("Secondary", function(object) standardGeneric("Secondary"))
 
 
 ### Others (do whatever you want with them ;-)
-setGeneric("dbconn", function(x) standardGeneric("dbconn"))
-setGeneric("dbfile", function(x) standardGeneric("dbfile"))
+setGeneric("taxonomyId", function(x) standardGeneric("taxonomyId"))
 setGeneric("dbmeta", signature="x", function(x, name) standardGeneric("dbmeta"))
 setGeneric("dbschema", signature="x", function(x, file="", show.indices=FALSE) standardGeneric("dbschema"))
 setGeneric("dbInfo", function(x) standardGeneric("dbInfo"))
@@ -73,17 +72,19 @@ setGeneric("saveDb", signature="x",
 
 setGeneric("packageName", function(x) standardGeneric("packageName"))
 
-setGeneric("columns", signature="x",
-           function(x) standardGeneric("columns"))
-
-setGeneric("keytypes", signature="x",
-           function(x) standardGeneric("keytypes"))
+setGeneric("columns", signature="x", function(x) {
+    value <- standardGeneric("columns")
+    sort(value)
+})
+           
+setGeneric("keytypes", signature="x", function(x) {
+    value <- standardGeneric("keytypes")
+    sort(value)
+})
 
 setGeneric("select", signature="x",
            function(x, keys, columns, keytype, ...) standardGeneric("select"))
 
-
-
 setGeneric("mapIds", signature="x",
-           function(x, keys, column, keytype, ..., multiVals) standardGeneric("mapIds"))
-
+           function(x, keys, column, keytype, ..., multiVals)
+               standardGeneric("mapIds"))
