@@ -20,15 +20,17 @@
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### The "ls" new generic.
 ###
-.ls <- function(name, pos, envir, all.names, pattern){
+.ls <- function(name, pattern, sorted){
         keys <- keys(name)
         if (!missing(pattern))
             keys <- keys[grep(pattern, keys)]
+        if (sorted)
+            keys <- sort(keys)
         keys
 }
 
 setMethod("ls", signature(name="Bimap"),
-    function(name, pos=-1L, envir=as.environment(pos), all.names=FALSE, 
+    function(name, pos=-1L, envir=as.environment(pos), all.names=FALSE,
              pattern, sorted=TRUE){
         if (!missing(pos))
           warning("ignoring 'pos' argument")
@@ -36,9 +38,7 @@ setMethod("ls", signature(name="Bimap"),
           warning("ignoring 'envir' argument")
         if (!missing(all.names))
           warning("ignoring 'all.names' argument")
-        if (!missing(sorted))
-          warning("ignoring 'sorted' argument")
-        .ls(name, pos, envir, all.names, pattern)
+        .ls(name, pattern, sorted)
     }
 )
 
