@@ -7,15 +7,29 @@
 .filterDeprecatedKeytypes <- function(keytypes){
     keytypes[!(keytypes %in% .listDeprecatedKeytypes())]
 }
+
+## this is a 'standard' warning for people who try to use keys or cols
+## that are no longer valid due to being deprecated
+.deprecatedColsMessage <- function(){
+    depCols <- paste(.listDeprecatedKeytypes(), collapse="','")
+    warning(wmsg(paste0("Accessing gene location information via '",
+                        depCols,"' is deprecated. Please use a range ",
+                        "based accessor like genes(), or select() with ",
+                        "columns values like TXCHROM and TXSTART ",
+                        "on a TxDb or OrganismDb object instead.\n")))
+}
+
 ## And one for keys and select to warn if the user tries to use them
 .checkForDeprecatedKeytype <- function(keytype){
     if(any(.listDeprecatedKeytypes() %in% keytype )){
-        warning(wmsg(paste0(keytype,
-    " is deprecated. ",
-    "Please use an appropriate TxDb object or package for this kind of data.")))
+        .deprecatedColsMessage()
     }
 }
 
+
+
+
+
 ## Need an accessor for getting the central ID for a DB (when appropriate)
 .getCentralID <- function(x){
   as.character(dbQuery(dbconn(x),
@@ -469,11 +483,11 @@
 }
 
 
-.getFullyQualifiedDBLocs <- function(x, cols){
-  tables <- .getDBLocs(x, cols, value="table")
-  fields <- .getDBLocs(x, cols, value="field")
-  paste(tables, fields, sep=".")
-}
+## .getFullyQualifiedDBLocs <- function(x, cols){
+##   tables <- .getDBLocs(x, cols, value="table")
+##   fields <- .getDBLocs(x, cols, value="field")
+##   paste(tables, fields, sep=".")
+## }
 
 
 ## x is the org package object, y is the chip package object. 
@@ -497,7 +511,8 @@
     ## because we have a "y" defined, we have to define the dblocs this way:
     dblocs <- .getDBLocs(y, cols)
     ## Fully qualified keytype and species are set up like this
-    fullKeytype <- .getFullyQualifiedDBLocs(y, keytype)
+    ## fullKeytype <- .getFullyQualifiedDBLocs(y, keytype)
+    fullKeytype <- .getDBLocs(y, keytype, value = "full.field")
     species <- species(x)
     ## if we have c.probes in dblocs, then we MUST join to genes table
     if("c.probes" %in% dblocs && species(x)!="Saccharomyces cerevisiae"){
@@ -508,15 +523,18 @@
     }
   }else{ ## this means there is only an org pkg...
     dblocs <- .getDBLocs(x, cols)
-    fullKeytype <- .getFullyQualifiedDBLocs(x, keytype)
+    ## fullKeytype <- .getFullyQualifiedDBLocs(x, keytype)
+    fullKeytype <- .getDBLocs(x, keytype, value = "full.field")
     species <- species(x)
   }
   
   ## Get fields
   if(exists("y", inherits=FALSE)){ ## IOW if it was a chip package at the top...
-    fields <- paste(.getDBLocs(y,cols,value="full.field"), collapse=",")
+    fields <- .getDBLocs(y,cols,value="full.field")
+    fields <- paste(paste(fields,paste0(fields,"'"),sep=" AS '"), collapse=",")
   }else{
-    fields <- paste(.getDBLocs(x,cols,value="full.field"), collapse=",")
+    fields <- .getDBLocs(x,cols,value="full.field")
+    fields <- paste(paste(fields,paste0(fields,"'"),sep=" AS '"), collapse=",")
   }
 
   
@@ -597,7 +615,7 @@
   #message(sql)
   ## get field names for relevant cols
   cols <- unique(c(keytype, cols))
-  headerTables <- .getDBLocs(x, cols, value="field")
+  headerTables <- .getDBLocs(x, cols, value="full.field")
   if(class(x)=="ChipDb"){
     y <- x ## save for test below
     x <- .getOrgPkg(x) ## then flip to using the org package
@@ -623,6 +641,9 @@
   blackList <- c(ALIAS="ALIAS2PROBE",
                  ALIAS="ALIAS2EG",
                  CHR="CHRLOCCHR")
+##                 CHR="CHRLOC",  ## Don't put cols here till removal is FINAL..
+##                 CHR="CHRLOCEND",
+##                 CHR="CHR")
   idx <- !(cols %in% blackList)
   unique(cols[idx])
 }
@@ -679,30 +700,37 @@
     ## 4 possibilities
     ## if there are not dups, then we skip this function.
     ## if(any(duplicated(keys)) ## expand the keys
-    ## if(any(duplicated(tab[[jointype]]))) ## expand the table...
+    ## if(any(duplicated(tab[[jointype]]))) ## some messages may apply
     ## AND if they are BOTH redundant how do I decide which row to expand?
     ## I think that I have to throw a warning and NOT do this step in that case?
     keyTest <- any(duplicated(keys))
     rowTest <-  any(duplicated(tab[[jointype]]))         
-    if (keyTest && !rowTest) { ## Need to account for row dups
+    if (keyTest ){ 
         ind = match(keys, tab[[jointype]])
         tab <- tab[ind,,drop=FALSE]
         rownames(tab) <- NULL
     }
-    ## We no longer aim to warn about these.  
-    ## Relevant manual pages may need to be more emphatic.
-#     else if (!keyTest && rowTest) {
-#         txt <- "'select' resulted in 1:many mapping between keys and
-#                 return rows"
-#         warning(paste(strwrap(txt), collapse="\n"))
-#     } else if (keyTest && rowTest) { ## User will get data "as is"
-#         txt <- "'select' and duplicate query keys resulted in 1:many
-#                 mapping between keys and return rows"
-#         warning(paste(strwrap(txt), collapse="\n"))
-#     }
+    ## We now just always give (terse) messages about relationship of
+    ## data to columns returned.
+    if(!keyTest && !rowTest) {
+        txt <- "'select()' returned 1:1 mapping between keys and columns"  
+    } else if (!keyTest && rowTest) {
+        txt <- "'select()' returned 1:many mapping between keys and columns"
+    } else if (keyTest && !rowTest) {
+        txt <- "'select()' returned many:1 mapping between keys and columns"
+    } else if (keyTest && rowTest) { ## User will get data "as is"
+        txt <- "'select()' returned many:many mapping between keys and columns"
+    }
+    message(paste(strwrap(txt), collapse="\n"))
     tab
 }
 
+##  select() returned 1:1 mapping between keys and columns
+##  select() returned 1:many mapping between keys and columns
+##  select() returned many:1 mapping between keys and columns
+## Also will want mesage for many:many
+
+
 ## .resort is the main function for cleaning up a table so that results look
 ## formatted the way we want them to.
 .resort <- function(tab, keys, jointype, reqCols) {
@@ -765,6 +793,11 @@
 
 ## the core of the select method for GO org and chip packages.
 .legacySelect <- function(x, keys=NULL, cols=NULL, keytype, jointype) {
+  ## IF CHR, CHR or CHRLOC are requested then you must deny the
+  ## request as these are now deprecated
+  if(any(.listDeprecatedKeytypes() %in% cols)){
+      .deprecatedColsMessage()
+  }
   ## if asked for what they have, just return that.
   if(all(cols %in% keytype)  && length(cols)==1){
     res <- data.frame(keys=keys)
@@ -781,11 +814,6 @@
   ## oriCols is a snapshot of col requests needed for column filter below
   oriCols <- unique(c(keytype, cols))
 
-  ## keys should NOT be NAs, but if they are, warn and then filter them.
-  if (any(is.na(keys))) {
-      warning("'NA' keys have been removed")
-      keys <- keys[!is.na(keys)]
-  }
 
   ## Check if the user is selecting too many cols with many:1 relationships
   .warnAboutManyToOneRelationships(cols)
@@ -795,10 +823,10 @@
   
   ## these are the colnames we need to have gotten back from the DB
   expectedCols <- .expandCols(x, oriCols)
-  oriTabCols <- .getDBLocs(x, expectedCols, value="field")
+  oriTabCols <- .getDBLocs(x, expectedCols, value="full.field")
   
   ## I need to know the jointype...
-  jointype <- .getDBLocs(x, keytype, value="field")
+  jointype <- .getDBLocs(x, keytype, value="full.field")
 
   ## Remove suffixes in case there were dups
   res <- .filterSuffixes(res)
@@ -809,7 +837,7 @@
   if(all(expectedCols %in%  oriCols) &&
      any(oriCols != expectedCols) ){
     ## We need to make it so that oriTabCols is in the SAME order as oriCols
-    oriTabCols <- .getDBLocs(x, oriCols, value="field")
+    oriTabCols <- .getDBLocs(x, oriCols, value="full.field")
     ## then we need to make expectedCols to match oriCols
     expectedCols <- oriCols
   }
@@ -920,7 +948,7 @@
   if (!is.character(cols)){
       stop("'columns' must be a character vector")
   }
-  pcols <- columns(x)
+  pcols <- c(columns(x), .listDeprecatedKeytypes())
   if(!all(cols %in% pcols) && !is.null(cols)){
       badCols <- cols[!(cols %in% pcols)]
       msg <- paste0("Invalid columns: ",paste(badCols, collapse=","),". Please use the columns method to see a listing of valid arguments.")
@@ -928,30 +956,48 @@
   }
 }
 
-.testForValidKeys <- function(x, keys, keytype){
+## fks is an alternate vector of keys to consult for validity.
+## Normally this will be NULL and the test function should consult
+## keys for the supplied keytype
+.testForValidKeys <- function(x, keys, keytype, fks=NULL){
   if (!is.character(keys)){
       stop("'keys' must be a character vector")
   }
-  ktKeys <- keys(x, keytype)
+  if(is.null(fks)){  ## Normally, fks is just NULL and so we will call keys()
+      ktKeys <- keys(x, keytype)
+  }else{             ## This lets the caller say wait: use these keys instead 
+      ktKeys <- fks 
+  }
   if(!(any(ktKeys %in% keys))){
       msg <- paste0("None of the keys entered are valid keys for '",keytype,
          "'. Please use the keys method to see a listing of valid arguments.")
-      stop(msg)
+      stop(msg) ## later when things are better, demote this to a warning()
   }
 }
 
-.testSelectArgs <- function(x, keys, cols, keytype){
+.testSelectArgs <- function(x, keys, cols, keytype, fks=NULL,
+                            skipValidKeysTest=FALSE){
     .testForValidKeytype(x, keytype)
     .testForValidCols(x, cols)
-    .testForValidKeys(x, keys, keytype)
+    ## I may need for this test to sometimes not happen...
+    if(skipValidKeysTest==FALSE){
+        .testForValidKeys(x, keys, keytype, fks)
+    }
 }
-
+## library(Homo.sapiens); select(Homo.sapiens, c('11'), 'SYMBOL', 'GENEID')
 
 ## general select function
-.select <- function(x, keys=NULL, cols=NULL, keytype, jointype){
-    ## Some argument checking
-    .testSelectArgs(x, keys=keys, cols=cols, keytype=keytype)
-    ## Now get the schema
+.select <- function(x, keys=NULL, cols=NULL, keytype, jointype, ...){
+    ## Some argument handling and checking
+    extraArgs <- list(...)
+    if('fks' %in% names(extraArgs)){fks<-extraArgs[["fks"]]}else{fks<-NULL}
+    if('skipValidKeysTest' %in% names(extraArgs)){
+        skipValidKeysTest<-extraArgs[["skipValidKeysTest"]]}else{
+            skipValidKeysTest<-FALSE}
+    .testSelectArgs(x, keys=keys, cols=cols, keytype=keytype,
+           fks=fks, skipValidKeysTest=skipValidKeysTest)
+    
+    ## Now get the schema and call select
     schema <- metadata(x)[metadata(x)$name=="DBSCHEMA",]$value
     if(schema=="NOSCHEMA_DB" || schema=="NOCHIPSCHEMA_DB"){
         .noSchemaSelect(x, keys, cols, keytype)
@@ -966,9 +1012,9 @@
 ## Helper for setting the jointype to an appropriate default
 .chooseJoinType  <- function(x){
   if(.getCentralID(x) == "ORF" && species(x) == "Saccharomyces cerevisiae"){
-    jointype <- "systematic_name"
+    jointype <- "gene2systematic.systematic_name"
   }else{
-    jointype <- "gene_id"
+    jointype <- "genes.gene_id"
   }
   jointype
 }
@@ -990,36 +1036,29 @@
 
 setMethod("select", "OrgDb",
           function(x, keys, columns, keytype, ...) {
-##               if (missing(keytype)){
-##                   keytype <- .chooseCentralOrgPkgSymbol(x)
-##               }
-              kt <- .chooseCentralOrgPkgSymbol(x)
+              if (missing(keytype)) keytype <- .chooseCentralOrgPkgSymbol(x)
               jointype <- .chooseJoinType(x)
-
-              .selectWarnJT(x, keys, columns, keytype, jointype=jointype,
-                            kt=kt, ...)
-              ## put back following line after 2.13 releases
- ##              .select(x, keys, columns, keytype, jointype=jointype)
+              .select(x, keys, columns, keytype, jointype=jointype, ...)
+              ## .selectWarnJT(x, keys, columns, keytype, jointype=jointype,
+              ##               kt=kt, ...)
           }
 )
 
 setMethod("select", "ChipDb",
     function(x, keys, columns, keytype, ...){
-##         if (missing(keytype)) keytype <- "PROBEID"
-        kt <- "PROBEID"
-        .selectWarnJT(x, keys, columns, keytype, jointype="probe_id",
-                      kt=kt, ...)
-        ## put back following line after 2.13 releases
-        ##           .select(x, keys, columns, keytype, jointype="probe_id")
+        if (missing(keytype)) keytype <- "PROBEID"
+        .select(x, keys, columns, keytype, jointype="probes.probe_id", ...)
+        ## .selectWarnJT(x, keys, columns, keytype, jointype="probes.probe_id",
+        ##               kt=kt, ...)
     }
 )
 
 setMethod("select", "GODb",
     function(x, keys, columns, keytype, ...){
           if (missing(keytype)) keytype <- "GOID"
-          .selectWarnJT(x, keys, columns, keytype, jointype="go_id", ...)
-          ## put back following line after 2.13 releases
-##           .select(x, keys, columns, keytype, jointype="go_id")
+          .select(x, keys, columns, keytype, jointype="go_term.go_id", ...)
+          ## .selectWarnJT(x, keys, columns, keytype, jointype="go_term.go_id",
+          ## ...)
         }
 )
 
@@ -1041,7 +1080,7 @@ setMethod("select", "GODb",
 ## cols methods return the list of things that users can ask for.  This can be
 ## just the table names, or it might be a list of mappings
 
-
+    
 .legacyCols <- function(x, baseType){
   ## cols <- .makeColAbbrs(x)
   cols <- names(.defineTables(x))
@@ -1049,8 +1088,11 @@ setMethod("select", "GODb",
     cols <- c(baseType, cols)
   }
   ## translate relevant short bimap names to "cute" names
-  ## cols <- .swapSymbolExceptions(x, cols) 
   cols <- .simplifyCols(x, cols)
+
+  ## filter out columns that have been deprecated here
+  hideCols <- .listDeprecatedKeytypes()
+  cols <- cols[!(cols %in% hideCols)]
   
   ## .cols does not care about your names
   names(cols) <- NULL
@@ -1680,7 +1722,7 @@ setMethod("keytypes", "GODb",
 ## Add 'filter' as a later option for multiVals which just means that the user needs to provide an actual function for the multiVals
 ## Add some of the arguments that are now supported by 'keys' to this function.
 
-setMethod("mapIds", "AnnotationDb", function(x, keys, column, keytype, ...,
+.mapIds <- function(x, keys, column, keytype, ...,
             multiVals=c("filter","asNA","first","list","CharacterList")){
     if(missing(multiVals)) multiVals <- 'first'
     ## make sure we have reasonable value for multiVals.
@@ -1696,10 +1738,10 @@ setMethod("mapIds", "AnnotationDb", function(x, keys, column, keytype, ...,
     
     ## next call select()
     ## TODO: remove the suppressWarnings() call once you get rid of that warning
-    res <- select(x, keys=keys, columns=column, keytype=keytype) 
+    suppressMessages(
+        res <- select(x, keys=keys, columns=column, keytype=keytype))
     ## then split accordingly (and return sorted by initial keys)
-    res <- split(res[[column]], f=res[[keytype]])[keys]
-
+    res <- split(as.character(res[[column]]), f=res[[keytype]])[keys]
     ## internal helper to toss out multiply matching things
     .filtMults <- function(data){
         idx <- sapply(data, FUN=function(x){
@@ -1722,15 +1764,24 @@ setMethod("mapIds", "AnnotationDb", function(x, keys, column, keytype, ...,
     }
     ## names will already be present
     res
-})
+}
+
+setMethod("mapIds", "AnnotationDb", function(x, keys, column, keytype, ...,
+      multiVals){.mapIds(x, keys, column, keytype, ..., multiVals=multiVals)})
 
 ## TODO: add option to replace multi-matches with NAs or to just remove them.
 ## To cleanly handle having 'multiVals' being EITHER a FUN or something else:
 ## DO like: if(is.function(multiVals)){}else{match.arg(multiVals)}
+## trace(mapIds, browser(), signature='AnnotationDb')
+## library(org.Hs.eg.db); mapIds(org.Hs.eg.db, c('1','10'), 'ENTREZID', 'ENTREZID')
 
 
+.taxonomyId <- function(x){
+    conn <- dbconn(x)
+    res <- dbGetQuery(conn,
+                      'SELECT value from metadata where name like "TAXID" or name like "Taxonomy ID"')
+    as.integer(res)
+}
 
-
-
-
+setMethod("taxonomyId", "AnnotationDb", function(x){.taxonomyId(x)})
 
