@@ -22,7 +22,7 @@ t <- org.At.tair.db
 s <- org.Sc.sgd.db
 cols <- c("CHR","PFAM","GO")
 keys <- c(1,10)
-jointype <- "gene_id"
+jointype <- "genes.gene_id" ## changed from 'gene_id'
 quiet <- suppressWarnings # quieten warnings from 1:many mappings in select()
 
 ## resort and friends are really important as they are generic enough to
@@ -31,7 +31,7 @@ test_generateExtraRows <- function(){
   ttab = data.frame(warpbreaks[1:10,])
   tkeys = ttab$breaks
   tkeys = c(26, tkeys[1:7], tkeys[7], 30, tkeys[8:10], tkeys[10])
-  res <- AnnotationDbi:::.generateExtraRows(ttab, tkeys, jointype)
+  res <- AnnotationDbi:::.generateExtraRows(ttab, tkeys, jointype='breaks')
   checkTrue(length(tkeys) == dim(res)[1])
 }
 
@@ -95,8 +95,9 @@ test_resort <- function() {
     keys <- c(1,10)
     res <- AnnotationDbi:::.extractData(x, cols, keytype="ENTREZID", keys)
     ## jumble res to simulate trouble
-    resRO = res[order(sort(res$gene_id,decreasing=TRUE)),]
-    reqCols <- c("gene_id","chromosome","symbol","pfam_id")
+    resRO = res[order(sort(res$genes.gene_id,decreasing=TRUE)),]
+    reqCols <- c("genes.gene_id","chromosomes.chromosome","gene_info.symbol",
+                 "pfam.pfam_id")
     Rres <- fun(resRO, keys, jointype, reqCols)
     checkIdentical(Rres$gene_id,Rres$gene_id)
     checkTrue(class(Rres) =="data.frame")
@@ -105,9 +106,9 @@ test_resort <- function() {
     keys <- c(1, keys, keys)
     cols <- c("CHR","SYMBOL")
     res <- AnnotationDbi:::.extractData(x, cols, keytype="ENTREZID", keys)
-    reqCols <- c("gene_id","chromosome","symbol")
+    reqCols <- c("genes.gene_id","chromosomes.chromosome","gene_info.symbol")
     res2 <- fun(res, keys, jointype, reqCols)
-    checkIdentical(as.numeric(as.character(res2$gene_id)),keys)
+    checkIdentical(as.numeric(as.character(res2$genes.gene_id)),keys)
     checkTrue(class(res) =="data.frame")
 }
 
@@ -143,7 +144,7 @@ test_keys <- function(){
 }
 
 test_keys_advancedArgs <- function(){
-    k1 <- head(keys(x, keytype="SYMBOL"))
+    k1 <- keys(x, keytype="SYMBOL")
     checkTrue("A1BG" %in% k1)
     
     k2 <- keys(x, keytype="SYMBOL", pattern="BRCA")
@@ -384,14 +385,13 @@ test_select15 <- function(){
     if(!all(.Platform$OS.type == "windows", .Platform$r_arch == "i386")){
         res <- select(x, keys="100008586", columns(x)) 
         checkTrue(dim(res)[1]>0)
-        checkTrue(dim(res)[2]==30)
-        checkIdentical(c('ENTREZID','PFAM','IPI','PROSITE','ACCNUM','ALIAS',
-                         'CHR', 'CHRLOC','CHRLOCCHR','CHRLOCEND','ENZYME',
-                         'MAP','PATH','PMID','REFSEQ','SYMBOL','UNIGENE',
-                         'ENSEMBL','ENSEMBLPROT','ENSEMBLTRANS','GENENAME',
-                         'UNIPROT','GO','EVIDENCE','ONTOLOGY','GOALL',NA,
-                         'ONTOLOGYALL','OMIM','UCSCKG'),
-                       colnames(res))
+        checkTrue(dim(res)[2]==26)
+        exp <- c("ENTREZID", "ACCNUM", "ALIAS", "ENSEMBL", "ENSEMBLPROT",
+                 "ENSEMBLTRANS", "ENZYME", "EVIDENCE", "EVIDENCEALL",
+                 "GENENAME", "GO", "GOALL", "IPI", "MAP", "OMIM", 
+                 "ONTOLOGY", "ONTOLOGYALL", "PATH", "PFAM", "PMID", "PROSITE",
+                 "REFSEQ", "SYMBOL", "UCSCKG", "UNIGENE", "UNIPROT")
+        checkIdentical(exp, colnames(res))
     }
 }
 
@@ -405,8 +405,50 @@ test_select16 <- function(){
     checkTrue(dim(res)[2]==2)
     checkIdentical(c('SYMBOL','PROBEID'), colnames(res))
 }
-## TODO: figure out why in this weird corner case there is an extra col for
-## GOALL called 'NA'...
+
+
+## NA values are now OK for legacySelect (in order to be consistent
+## with other select methods which have greater respect for incoming NA values
+test_select_NAsInNAsOut <- function(){
+    ## NAs in should result in NAs out.
+    ## Not that we like NAs but just because if possible: we want to
+    ## preserve the geometry of the keys coming in.
+    k=c('1', NA, NA, '10');
+    res <- select(x, k, 'SYMBOL', 'ENTREZID')
+    checkTrue(dim(res)[1]==4) 
+    checkTrue(dim(res)[2]==2)
+    checkIdentical(c('ENTREZID','SYMBOL'), colnames(res))
+    checkIdentical(k, res$ENTREZID)
+    checkTrue(any(is.na(res$SYMBOL)))
+}
+
+
+## Some new messages from AnnotationDbi:::.generateExtraRows()
+## where I am calling it internally...
+## these tests just make sure the right kinds of messages are being sent...
+test_select_XtoX <- function(){
+    k=c('1','1', NA, '10');
+    res <- tryCatch(select(org.Hs.eg.db, k, 'SYMBOL', 'ENTREZID'),
+                    message = function(x){return(x)})
+    checkTrue(grepl('many:1', res$message))
+    
+    res <- tryCatch(select(org.Hs.eg.db, '1', 'ALIAS', 'ENTREZID'),
+                    message = function(x){return(x)})
+    checkTrue(grepl('1:many', res$message))
+
+    res <- tryCatch(select(org.Hs.eg.db, k, 'ALIAS', 'ENTREZID'),
+                    message = function(x){return(x)})
+    checkTrue(grepl('many:many', res$message))
+
+    res <- tryCatch(select(org.Hs.eg.db, c('1','10'), 'SYMBOL', 'ENTREZID'),
+                    message = function(x){return(x)})
+    checkTrue(grepl('1:1', res$message))
+}
+
+
+## TODO: deal with any fallout from having new messages in select()
+## This will also cause me to have to silence select() in many places
+## to avoid annoying repeats of the
 
 
 
@@ -420,3 +462,9 @@ test_dbconn_and_dbfile <- function(){
     mf <- dbGetQuery(dbConnect(SQLite(), resf), "SELECT * FROM metadata")
     checkTrue(all(mf == m))
 }
+
+
+
+
+## Fast checking:
+## BiocGenerics:::testPackage(pattern="^test_select.*\\.R$")
